package com.tanpu.community.manager;

import com.alibaba.fastjson.JSON;
import com.tanpu.biz.common.enums.clue.PageEnum;
import com.tanpu.community.api.beans.vo.KafkaDurationUptMsg;
import com.tanpu.community.dao.entity.community.VisitLogEntity;
import com.tanpu.community.service.VisitLogService;
import com.tanpu.community.util.ConvertUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.kafka.annotation.KafkaListener;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.List;

@Slf4j
@Service
public class VisitSummaryManager {

    private static final String kafakTopic = "tp_new_community_queue_ubr_dur_upd";

    @Autowired
    private KafkaTemplate<String, String> kafkaTemplate;

    @Autowired
    private VisitLogService visitLogService;


    List<String> PAGEID_NEED_SAVE = Arrays.asList(PageEnum.COMM_VISIT_HOME_PAGE.getId(), PageEnum.COMM_VISIT_THEME.getId());
    @KafkaListener(topics = kafakTopic)
    public void updateVisitSummary(String message) {
        // {"durMillsInc":10000,"ident":"AD7B8CE8-2DA4-4FB4-907F-C551B926BA5C","localDate":"2021-08-02","pageId":"p13503","refId":"88737580570230824","visitorId":"275321532031467520"}
        log.info("receive kafka msg: {}", message);
        KafkaDurationUptMsg msg = JSON.parseObject(message, KafkaDurationUptMsg.class);
        // 做一个筛选
        if (!PAGEID_NEED_SAVE.contains(msg.pageId)) {
            return;
        }
        // ident在每次进入新页面 & 回退 的时候都会随机生成一个，所以用ident做唯一key即可。
        VisitLogEntity vs = ConvertUtil.convertFromKafka(msg);
        visitLogService.insertOrUpdateDur(vs);
    }
}
